# More information and contact us

For all your enquiries and questions, please contact us at info@book-analytics.org.

[Book Analytics Service](https://oapen.org/article/book-analytics-service) key information page, including how to get started


Information about the [Mellon Foundation](https://mellon.org/) funded Book Analytics Dashboard (BAD) project (2022-2025)

* [Visit the BAD project website](http://book-analytics.org/)
* Follow the BAD project on Twitter [@BookAnalytics](https://twitter.com/BookAnalytics)
* [Join the BAD project mailing list](https://docs.google.com/forms/d/e/1FAIpQLSdt7m9xL_4LxY3RUlX7DFg9uq7_12c8NLtDj036eGIZszPONA/viewform)
* [Visit the BAD project Zenodo community](https://zenodo.org/communities/book-analytics-dashboard-project/?page=1&size=20)
* [See the BAD template dashboard](http:/template.book-analytics.org/), powered by the University of Michigan Press' data
* [Our book-focussed GitHub repository](https://github.com/The-Academic-Observatory/oaebu-workflows)

Running in parallel with the Book Analytics Dashboard project is the [OA Book Usage Data Trust](https://www.oabookusage.org/), a project to formalise community governance mechanisms, quantify data trust participation benefits, and understand the full operational costs related to an international data space for OA book usage.
